@@ -2,10 +2,9 @@ CURRENCY_DEFAULT = "руб."
 DEFAULT_USER_AGENT = (
     "Mozilla/5.0 (Windows NT 10.0; Win64; x64) "
     "AppleWebKit/537.36 (KHTML, like Gecko) "
-    "Chrome/76.0.3809.100 Safari/537.36"
+    "Chrome/92.0.4515.107 Safari/537.36 Edg/92.0.902.55"
 ).strip()
 
-
 FIELD_PROVIDER_TYPE = "kd_provider"
 FIELD_SERVICE_TYPE = "kd_service_type"
 
